#
# spec file for package jameica
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _major 2
%define _minor 10
%define _micro 5
%define _build 488
%define _buildreleases 488
%define _version %{_major}.%{_minor}.%{_micro}
%define _tag V_%{_major}_%{_minor}_%{_micro}_BUILD_%{_build}

Name:           jameica
Version:        %{_version}
Release:        2.2
Summary:        Runtime environment for Java applications like Hibiscus
License:        Apache-2.0 AND GPL-2.0-only AND LGPL-2.0-only AND CPL-1.0 AND Zlib AND MPL-1.0 AND EPL-1.0
Group:          Productivity/Office/Finance
URL:            http://www.willuhn.de/products/jameica/
Source:         https://github.com/willuhn/jameica/archive/%{_tag}.tar.gz
Source99:       %{name}-rpmlintrc
BuildRequires:  ant
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  java-devel >= 17
BuildRequires:  jpackage-utils
BuildRequires:  xml-apis
Requires:       java >= 17
Requires:       libgthread-2_0-0

%ifarch %{ix86} ppc s390
%global bits 32
%endif
%ifarch x86_64 ia64 s390x aarch64 armv7l arm64
%global bits 64
%endif
%if 0%{?__isa_bits}
%global bits %{__isa_bits}
%endif

%description
Serves as a base framework for recurring tasks on Hibiscus.
Keeps a unified look & feel. Strictly separate program and
user data. Supports synchronous and asynchronous data exchange
via between plugins (via messaging) and allows client server
communication via RMI, XML-RPC and SOAP. Comes with headless
mode (no GUI for servers) and logging.

%package devel
Summary:        SDK for the Jameica framework
Group:          Development/Languages/Java
Requires:       jameica
BuildArch:      noarch

%description devel
Source code required to build and develop Jameica plugins.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description javadoc
Developer documentation for Jameica.

%prep
%setup -q -n %{name}-%{_tag}
# rpmlint
find . -type f -name '*.txt' -exec chmod -x {} \;
find . -type f -name '*.html' -exec chmod -x {} \;
find . -type f -name '*.properties' -exec chmod -x {} \;

rm build/jameica-win32.exe
rm build/jameica-win64.exe
rm build/launch4j-win32.xml
rm build/launch4j-win64.xml
rm build/jameica-macos64.sh
rm build/jameica-macos-aarch64.sh
rm build/jameica-openbsd.sh

rm -rf lib/swt/macos64
rm -rf lib/swt/macos-aarch64
rm -rf lib/swt/win32
rm -rf lib/swt/win64
# remove arm because of missing ld-linux-aarch64.so.1 package in suse
rm -rf lib/swt/linux-arm64

%build
export CLASSPATH="$(build-classpath xml-apis)"
ant -f build/build.xml init compile jar zip src javadoc

%install
mkdir -p %{buildroot}%{_prefix}/lib/jameica/plugins
cp -r releases/%{version}-%{_buildreleases}/%{name} %{buildroot}%{_prefix}/lib
chmod +x %{buildroot}%{_prefix}/lib/%{name}/rcjameica
chmod +x %{buildroot}%{_prefix}/lib/%{name}/jameicaserver.sh
chmod +x %{buildroot}%{_prefix}/lib/%{name}/jameica.sh

rm %{buildroot}%{_prefix}/lib/%{name}/jameica-win32.jar
rm %{buildroot}%{_prefix}/lib/%{name}/jameica-win64.jar
rm %{buildroot}%{_prefix}/lib/%{name}/jameica-macos64.jar
rm %{buildroot}%{_prefix}/lib/%{name}/jameica-macos-aarch64.jar
rm %{buildroot}%{_prefix}/lib/%{name}/jameica-openbsd.jar

%if "%{bits}" == "64"
rm %{buildroot}%{_prefix}/lib/%{name}/jameica-linux.jar
  %ifarch aarch64 armv7l arm64
  rm %{buildroot}%{_prefix}/lib/%{name}/jameica-linux64.jar
  %else
  rm %{buildroot}%{_prefix}/lib/%{name}/jameica-linuxarm64.jar
  %endif
%else
  rm %{buildroot}%{_prefix}/lib/%{name}/jameica-linux64.jar
%endif

# Mac OS X stuff
rm %{buildroot}%{_prefix}/lib/%{name}/*.plist
rm %{buildroot}%{_prefix}/lib/%{name}/*.icns

mkdir -p %{buildroot}%{_bindir}
ln -sf %{_prefix}/lib/%{name}/jameica.sh %{buildroot}%{_bindir}/jameica
ln -sf %{_prefix}/lib/%{name}/jameicaserver.sh %{buildroot}%{_bindir}/jameicaserver

cp -r src %{buildroot}%{_prefix}/lib/jameica

mkdir -p %{buildroot}%{_javadocdir}/%{name}-%{version}
cp -r releases/%{version}-%{_buildreleases}/javadoc/* %{buildroot}%{_javadocdir}/%{name}-%{version}

%fdupes %{buildroot}%{_prefix}/lib/%{name}

%files
%doc build/ChangeLog README.md
%license LICENSE COPYING
%{_bindir}/*
%{_prefix}/lib/jameica
%{_prefix}/lib/jameica/lib
%dir %{_prefix}/lib/jameica/plugins
%exclude %{_prefix}/lib/jameica/src

%files devel
%{_prefix}/lib/jameica/src

%files javadoc
%{_javadocdir}/%{name}-%{version}

%changelog
* Wed Feb 19 2025 ecsos <ecsos@opensuse.org>
- Fix boo#1237326. Jameica can not be start.
  Remove BuildArch: noarch and add rpmlintrc file.
  If BuildArch is set to noarch, then an arch query no longer seems
  to work under Tumbleweed.
* Fri Feb 14 2025 ecsos <ecsos@opensuse.org>
- Update to 2.10.5
  - NEW: 0185 Wir liefern jetzt sowohl MariaDB- als auch MySQL-Treiber mit
  - NEW: 0184 Wenn Anwendung im Maximiert-Zustand beendet, dann Fenster-Größe nicht speichern.
    Beim Start auch dann Fenster-Größe setzen, wenn im Maximiert-Zustand gestartet wird
  - BUG: 0183 Pfad zur Jameica JAR-Datei in jameica-macos-aarch64.sh falsch
  - NEW: 0182 Update auf SWT 4.33 für linux64, linux-arm64, win64, macos64,
    macos64-aarch64 sowie Java 21 auf win64, macos64, macos64-aarch64
  - NEW: 0181 Nur einen Hintergrund-Task in der GUI zur gleichen Zeit zulassen
  - BUG: 0180 Selectboxen wurden nicht farbig hervorgehoben, wenn sie als Pflichtfelder markiert waren
  - BUG: 0179 CTRL+A und CTRL+C funktionierte nicht bei Tabellen, die kein Kontextmenü besitzen
  - NEW: 0178 Drag'n'Drop-Support für Attachments
  - NEW: 0177 Ordner für Dateianhänge kann jetzt auch wieder auf System-Default zurückgesetzt werden.
    Außerdem wird der aktuell verwendete Ordner angezeigt
  - NEW: 0176 Auf der Startseite einen Hinweis anzeigen, wenn in der letzten Sitzung
    Fehler dazu führten, dass kein automatisches Backup erstellt werden konnte
  - BUG: 0175 Beim Restore aus dem Systray Fenster forciert in Vordergrund bringen
  - NEW: 0174 Wenn Minimieren in Systray aktiviert ist, dann auch beim Klick auf Schliessen-Kreuz
    im Fenster-Titel nicht beenden sondern in Systray minimieren
  - CHG: 0173 Umstellung des JDBC-Treibers von MySQL auf MariaDB
  - CHG: 0172 Rahmen um Slider unter Windows entfernt - das Problem mit der Hintergrundfarbe
    existiert in aktuellen Windows-/SWT-Versionen nicht mehr
* Wed Feb  5 2025 Fridrich Strba <fstrba@suse.com>
- Fix build with recent Factory macro changes
* Thu Jan 16 2025 ecsos <ecsos@opensuse.org>
- Add missing require libgtread-2_0-0.
* Sun Mar 24 2024 ecsos <ecsos@opensuse.org>
- Drop all unbundle things, and use source completely from upstream,
  because unbundling is more work to do and it repeatedly generates
  unnecessary errors. And also it use sometimes to old libraries.
- Drop jameica-port-to-commons-lang3.patch because we use only code
  from upstream.
- Drop unnecessary buildrequires.
- Fix some rpmlint errors.
* Sun Feb 25 2024 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * jameica-port-to-commons-lang3.patch
    + port jameica to use apache-commons-lang3 instead of the old
    apache-commons-lang
- Unbundle the jakarta_commons jars
* Sun Feb 25 2024 Fridrich Strba <fstrba@suse.com>
- The unbundled velocity-1.7 depends on apache-commons-lang3 (bsc#1220289)
* Sun Apr 16 2023 ecsos <ecsos@opensuse.org>
- Update to 2.10.4
  - NEW: 0171 Update auf SWT 4.27 für linux64, linux-arm64, win64, macos64, macos64-aarch64
  - NEW: 0170 Hinweisbox, wenn Repositories von Drittanbietern aktiviert sind
  - NEW: 0169 Neue Option, um die Anwendung in das System-Tray zu minimieren
  - NEW: 0168 Support für Java 15+ (Jameica liefert jetzt JavaScript Engine Rhino mit)
  - NEW: 0167 Update auf SWT 4.26 für linux64, linux-arm64, win64,
    macos64, macos64-aarch64 sowie Update von JFace auf 3.28
  - NEW: 0166 F5 als Shortcut zum Reload einer View
  - NEW: 0165 An nahezu alle Dialoge können jetzt Dateien angehängt
    werden (mit dem Büroklammer-Symbol oben rechts)
  - NEW: 0164 Update auf BouncyCastle 1.72. Bisherige Version ist von CVE-2020-15522 betroffen.
  - NEW: 0163 TXW2 gegen die zu JAXB Runtime passende, versionsgleiche Bibliothek austauschen
  - BUG: 0162 In Selectboxen nicht mehr auf FocusIn- und FocusOut-Events bei Listenern reagieren
* Wed Jan 25 2023 ecsos <ecsos@opensuse.org>
- Update to 2.10.3
  - NEW: 0161 Optionales Logo-Part für mehr Customizing-Möglichkeiten.
    Empfang der Statusbar-Messages direkt durch das Notification-Panel.
    Hat den Vorteil, dass man das Notification-Panel auch an anderer Stelle verwenden kann.
  - NEW: 0160 Anzahl der Einträge in Auswahldialog der Jameica-Benutzerverzeichnisse auf 8 erhöht
  - NEW: 0159 Titelleisten der Panel etwas höher darstellen
  - NEW: 0158 Seriennummern der Zertifikate in HEX-Schreibweise anzeigen
  - NEW: 0157 Support für Subject-Alt-Name im Hostname-Verifier
  - CHG: 0156 Repository-URL von JVerein auf die neue URL des Forks
    „OpenJVerein“ umgestellt: https://openjverein.github.io/jameica-repository
  - BUG: 0155 Systemsprache en_GB/en_US korrekt in der Auswahlbox
    unter Datei→Einstellungen erkennen
  - NEW: 0154 Neuer Customizing-Parameter „application.zoom.image=150/200/300“,
    um in Wayland Icons mit höherer Auflösung auch dann zu verwenden,
    wenn -„Dswt.autoScale=false“ gesetzt ist
  - BUG: 0153 Bei CTRL+A in Tabellen unter Windows wurde anschließend
    das Refresh-Event nicht ausgelöst, um z.Bsp. die Summenzeile zu aktualisieren
* Wed Jun  8 2022 ecsos <ecsos@opensuse.org>
- Update to 2.10.2
  - NEW: 0152 JRE-Update auf 11.0.15 (Windows 32/64Bit und MacOS 64Bit)
  - BUG: 0151 Macos AArch64 Pfade korrigiert
  - NEW: 0150 Kalender auf dunklen Themes farbig passend gestalten
  - NEW: 0149 Support für Java 18 - Security-Manager nicht mehr im
    System registrieren. Java 18+ unterstützt keinen Security-Manager mehr
  - NEW: 0148 Support für CTRL+A in Tabellen und Trees unter Windows
    zum Markieren aller Datensätze (funktionierte bisher nur unter Linux)
  - BUG: 0147 Scripting-Plugins bei der Wiederherstellung eines Backups korrekt anzeigen
  - NEW: 0146 Trust-Manager-Implementierung nicht mehr anhand „java.vendor“ auswählen
    sondern erst SunX509 versuchen. Wenn das fehlschlägt, dann Fallback auf IbmX509
  - NEW: 0145 Nachtrag zu #0144 - CMD-Taste statt STRG unter MacOS und Timeout
    für Logfenster von 30 auf 60 Sekunden erhöht
  - NEW: 0144 STRG+A im Logfenster möglich sowie Button „Text kopieren“
  - NEW: 0143 Referenz auf JAR-File in jameica-macosaarch64.sh falsch
* Tue Jan  4 2022 ecsos <ecsos@opensuse.org>
- Update to 2.10.1
  - NEW: 0142 Update auf SWT 4.20 für linux64, linux-arm64, win64, macos64
  - NEW: 0141 Support für Macos-aarch64 (SWT 4.20)
  - NEW: 0140 JRE-Update für Windows und Mac auf 11.0.13_8
  - NEW: 0139 MySQL-Treiber auf 5.1.49 aktualisiert - siehe
    https://homebanking-hilfe.de/forum/topic.php?t=24614
  - NEW: 0138 Update auf SWT 4.19M3 für macos64 - das Druckproblem
    https://bugs.eclipse.org/bugs/show_bug.cgi?id=569185 scheint dort behoben zu sein
  - NEW: 0137 Update auf SWT 4.18 für linux64, linux-arm64, win64 und macos64
* Sun Nov 29 2020 ecsos <ecsos@opensuse.org>
- Update to 2.10.0
  - NEW: 0136 Neue Launcher für Windows mit aktualisierter
    Versionsnummer
  - NEW: 0135 JRE-Update für Windows und Mac auf 11.0.9.1_1
  - NEW: 0134 Update auf SWT 4.17 für für linux64, linux-arm64
    (jetzt offiziell von Eclipse untestützt), win64 und macos64
  - NEW: 0133 Parameter „-Dsun.security.smartcardio.library“ zu
    jameica-macos64.sh hinzugefügt - für MacOS Big Sur nötig
  - siehe https://homebanking-hilfe.de/forum/topic.php?p=157884#real157884
  - NEW: 0132 Fenster-Position auch im Maximiert-Zustand speichern
  - siehe https://homebanking-hilfe.de/forum/topic.php?p=157397#real157397
  - NEW: 0131 Sprache wieder per Datei→Einstellungen konfigurierbar
  - NEW: 0130 Update auf SWT 4.14 für linux64, win64 und macos64
  - für die 32Bit-Plattformen gibt es keine neueren SWT-Versionen
    mehr (mit dieser Version werden in GTK3 auch endlich die
    Theme-Farben auf dem Plasma-Desktop korrekt berücksichtigt)
  - BUG: 0129 Fehlender Scrollbalken in der Liste der Zertifikate
    unter Datei→Einstellungen
  - NEW: 0128 Funktion zum Ein-/Ausblenden der Navigation
  - NEW: 0127 Neues Plugin-Repository https://hibiscus.tvbrowser.org
    aufgenommen
* Tue May 12 2020 ecsos <ecsos@opensuse.org>
- Update to 2.8.6
  - DEL: 0126 Support für 32Bit MacOS entfernt
  - NEW: 0125 Unterstützung für Linux ARM64
  - NEW: 0124 Bei Win32, Win64 und MacOS64 ist jetzt eine embedded
    JRE mit enthalten
- Comment out unbundle eclipse-swt, because it rise up build error.
* Wed Jan 29 2020 Fridrich Strba <fstrba@suse.com>
- Use our own eclipse-swt package to provide swt.jar
* Thu Oct 17 2019 ecsos@opensuse.org
- Update to 2.8.5
  - BUG: 0123 Fehler werfen, wenn ein Plugin zwar signiert ist, die
    zugehörige Plugin-Gruppe im Repository aber kein Zertifikat zur
    Validierung enthält
  - NEW: 0122 Shortcut „CTRL+Q“ zum Beenden des Programms
  - NEW: 0121 Repository-URL von JVerein auf HTTPS umgestellt
  - CHG: 0120 Aktualisiere Windows-Launcher mit Launch4J 3.12 und
    optionaler Suche in „%%JAVA_HOME%%“ (nötig für OpenJDK, weil das
    nicht installiert sondern nur entpackt wird und damit nicht in
    der Windows-Registry registriert wird)
  - CHG: 0119 Button-Beschriftung beim erneuten Installieren
    nochmal angepasst. „Aktualisieren…“ wenn die verfügbare Version
    neuer ist, sonst „Erneut installieren…“
  - NEW: 0118 Aktualisierte H2-Version h2-1.4.199
  - BUG: 0117 Dialog „Über…“ konnte u.U. wegen falschem
    XML-Escaping nicht angezeigt werden
  - CHG: 0116 Button-Beschriftung beim erneuten Installieren eines
    bereits installierten Plugins geändert von „Aktualisieren…“ zu
    „Erneut installieren…“
  - NEW: 0115 Aktualisierte H2-Version h2-1.4.198
* Sun May  5 2019 ecsos@opensuse.org
- Update to 2.8.4
  - BUG: In der Liste der verfügbaren Plugins kam es zu einem
    Fehler, wenn dort Scripting-Plugins enthalten waren -
    Proxy.newProxyInstance hat scheinbar in Java das Verhalten
    geändert, wenn der Classloader NULL ist
- Changes from 2.8.3
  - CHG: Popups verwenden jetzt als Fallback eigene Farben für
    Vorder- und Hintergrund, wenn keine Systemfarben vorgegeben
    sind oder Vorder- und Hintergrund identisch wären
  - CHG: Jameica verwendet jetzt unter Linux per Default GTK3
    (siehe „SWT_GTK3=1“ in jameica.sh)
  - NEW: Update auf SWT 4.9 (in 4.10 gibt es keine
    32Bit-Unterstützung mehr)
  - NEW: Hostname für das beim ersten Start zu erstellende
    System-Zertifikat kann jetzt per Konfigurationsdatei vorgegeben
    werden (Parameter „jameica.hostname“ in
    „de.willuhn.jameica.system.ApplicationCallback.properties“)
  - siehe https://homebanking-hilfe.de/forum/topic.php?p=141994#real141994
  - CHG: JVM-Parameter „-Dswt.autoScale=quarter“ bei den
    Windows-Launchern hinzugefuegt
  - siehe https://github.com/willuhn/jameica/commit/82d253c0e1aec918b98eb378027ebf2d2e5fb411
  - BUG: Kleiner Darstellungsfehler: Beim mehrfachen Überfahren der
    Panelbuttons mit der Maus oben rechts wurde unter dem Button
    eine 1 Pixel schmale dunkle Linie angezeigt
  - BUG: Die Bibliothek „oro“ fehlte im Ordner „lib/velocity“.
    Dadurch kam es zu einer ClassNotFoundException in SynTAX beim
    Erstellen der IDEA-Auswertung
  - BUG: Zoom-Faktor bei HiDPI-Displays wurde beim Druck von
    Dokumenten via de.willuhn.jameica.gui.internal.action.Print
    nicht deaktiviert, sodass Dokumente zu gross gedruckt wurden
  - NEW: MySQL-Treiber von 5.1.41 auf 5.1.47 aktualisiert
  - CHG: Settings nur noch maximal 1 mal pro Sekunde neu laden
  - NEW: Annotation „@Resource“ unterstützt jetzt auch Services des
    Typs „Bootable“.
  - NEW: 0102 BUGZILLA 1867 - HTTP-Redirects (für Wechsel von
    HTTP auf HTTPS) berücksichtigen
* Thu Dec  6 2018 Fridrich Strba <fstrba@suse.com>
- Build against generic xml-apis provider instead of
  xerces-j2-xml-apis
* Fri Nov 30 2018 ecsos@opensuse.org
- Update to 2.8.2
  - NEW: 0101 Support für Java 11
    (Umgebungsvariable „JDK_JAVA_OPTIONS='–add-modules=java.se.ee'“
    entfernt, Jameica liefert die nötigen JAR-Dateien in lib/java_ee
    jetzt selbst mit)
  - BUG: 0100 Aktualisierte H2-Version h2-1.4.197.
    Version 1.4.193 konnte beim Update auf Hibiscus 2.8.4 u.U. den
    Fehler „Concurrent update in table „SYS_ID“: another
    transaction has updated or deleted the same row [90131-193]“
    auslösen.
* Tue Jul 17 2018 ecsos@opensuse.org
- update to 2.8.1
  - BUG: 0099 BUGZILLA 1856 - Änderung in Bug 1852 betraf zu viele
    Plugins, Interpretation der abhängigen Versionsnummern nochmal
    so angepasst, dass das neue Verhalten nur gilt, wenn das
    „+“/„-“ in Klammern angegeben ist, ansonsten gilt wieder das
    vorherige Verhalten
  - BUG: 0098 Button „Übernehmen“ im Auswahlfenster für den
    Benutzerordner wurde nicht korrekt freigegeben
  - BUG: 0097 Jameica-Fenster wurde bei Dualscreen-Setup unter
    bestimmten Bedingungen nicht auf dem tatsächlichen sondern auf
    dem primären Monitor wiederhergestellt
  - NEW: 0096 BUGZILLA 1852 - Definition der Versionsnummern von
    abhängigen Plugins erweitert. Wenn z.Bsp. „1.1.2+“ definiert
    ist, erlaubt das nur noch „1.1.2“ - „1.1.(x>2)“. Vorher war
    z.Bsp. auch „1.2“ erlaubt
  - BUG: 0095 Die Prüfung, ob sich der Benutzerordner innerhalb
    des Programmordners befindet, war zu streng (schlug auch an,
    wenn der Name des Benutzerordners mit dem Namen des
    Programmordners beginnt)
  - BUG: 0094 Fortschrittsfenster mit Logausgaben wurde u.U. zu
    früh automatisch geschlossen, wenn mehrere Tasks direkt
    nacheinander ausgeführt werden
  - BUG: 0093 Bei der Frage „Jameica scheint bereits zu laufen…“
    wurde ein zusätzliches leeres Fenster angezeigt
    (siehe 0079 und 0074)
  - NEW: 0092 Default-Größe und Position des Hauptfensters optimiert
* Tue Jul 17 2018 ecsos@opensuse.org
- update to 2.8.0
  - NEW: 0091 BUGZILLA 1731 - Besserer Support für HiDPI-Monitore
  - DEL: 0090 Logo-Panel oben rechts entfernt - kostete nur Platz
  - NEW: 0089 Globale Suche nach oben rechts verlegt und mit
    Notification-Panel zusammengefasst
  - NEW: 0088 Komplettes Redesign der Dialoge für Plugins, Updates,
    Verwaltung der Repositories, usw.
  - CHG: 0087 JVM-Parameter „-Xss“ in jameicaserver.sh wieder
    entfernt.
    Siehe http://www.onlinebanking-forum.de/forum/topic.php?p=136651#real136651
  - NEW: 0086 Beim Herunterladen mehrere abhängiger Plugins erst am
    Ende den Hinweis zum Neustart anzeigen
  - NEW: 0085 Beim Installieren von Plugins per „Datei→Plugins
    online suchen…“ nur dann nach Zielordner fragen, wenn mehrere
    zur Wahl stehen
  - NEW: 0084 Langen Text in Passwort-Dialog bei kleinen Displays
    scrollbar machen.
    Siehe http://www.onlinebanking-forum.de/forum/topic.php?t=21572&highlight=&page=last#last_post
  - NEW: 0083 Support für Java 9
  - NEW: 0082 Überschreiben der Sortierung von Werten in
    abgeleiteten Klassen von „Column“ erlauben
* Wed Feb  7 2018 mailaender@opensuse.org
- unbundle velocity
* Mon Dec 26 2016 mailaender@opensuse.org
- update to version 2.6.6
- add missing requires
* Sat Jul  9 2016 mailaender@opensuse.org
- unbundle NanoXML
* Sat Jul  9 2016 mailaender@opensuse.org
- unbundle PaperClips
* Sat Jul  9 2016 mailaender@opensuse.org
- update to version 2.6.4
- avoid the volatile current version ZIP by using GitHub tags
* Wed Apr 20 2016 mailaender@opensuse.org
- update to version 2.6.3
* Wed Dec 30 2015 mailaender@opensuse.org
- add a javadoc package
- unbundle swtcalendar
* Wed Dec 31 2014 mailaender@opensuse.org
- update to version 2.6.2
* Fri May 16 2014 mailaender@opensuse.org
- update to version 2.6.1
* Wed Jan  8 2014 mailaender@opensuse.org
- update to version 2.6.0
* Sat Nov 16 2013 mailaender@opensuse.org
- initial packaging of version 2.4
